/* 
 * Copyright 2004-2006 OpenSymphony 
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not 
 * use this file except in compliance with the License. You may obtain a copy 
 * of the License at 
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0 
 *   
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT 
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the 
 * License for the specific language governing permissions and limitations 
 * under the License.
 */
package org.quartz.listeners;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.quartz.SchedulerListener;
import org.quartz.Trigger;
import org.quartz.SchedulerException;

/**
 * A helpful abstract base class for implementors of 
 * <code>{@link org.quartz.SchedulerListener}</code>.
 * 
 * <p>
 * The methods in this class are empty so you only need to override the  
 * subset for the <code>{@link org.quartz.SchedulerListener}</code> events
 * you care about.
 * </p>
 * 
 * @see org.quartz.SchedulerListener
 */
public abstract class SchedulerListenerSupport implements SchedulerListener {
    private final Log log = LogFactory.getLog(getClass());

    /**
     * Get the <code>{@link org.apache.commons.logging.Log}</code> for this
     * class's category.  This should be used by subclasses for logging.
     */
    protected Log getLog() {
        return log;
    }

    public void jobScheduled(Trigger trigger) {
    }

    public void jobUnscheduled(String triggerName, String triggerGroup) {
    }

    public void triggerFinalized(Trigger trigger) {
    }

    public void triggersPaused(String triggerName, String triggerGroup) {
    }

    public void triggersResumed(String triggerName, String triggerGroup) {
    }

    public void jobsPaused(String jobName, String jobGroup) {
    }

    public void jobsResumed(String jobName, String jobGroup) {
    }

    public void schedulerError(String msg, SchedulerException cause) {
    }

    public void schedulerShutdown() {
    }
}
